@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: tabs-menu.c,v 1.3 2004/08/26 19:51:45 chpe Exp $
+ *  $Id: tabs-menu.c,v 1.5 2004/12/08 15:33:53 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,6 +31,8 @@
 #include <gmodule.h>
 #include <glib/gi18n-lib.h>
 
+G_MODULE_EXPORT GType register_module (GTypeModule *module);
+
 G_MODULE_EXPORT GType
 register_module (GTypeModule *module)
 {
@@ -42,7 +44,7 @@ register_module (GTypeModule *module)
 
 #ifdef ENABLE_NLS
        /* Initialise the i18n stuff */
-        bindtextdomain (GETTEXT_PACKAGE, EPHY_PLUGINS_LOCALEDIR);
+        bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");	
 #endif /* ENABLE_NLS */
 
